pub fn urisafe_instrument_id(instrument_id: &str) -> StringExpand description
Converts an instrument ID to a URI-safe format by removing forward slashes and replacing carets with underscores. Some instrument IDs contain forward slashes (e.g., “BTC/USD”) which are not suitable for use in file paths.